climind package
===============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   climind.config
   climind.data_manager
   climind.data_types
   climind.fetchers
   climind.plotters
   climind.readers
   climind.stats
   climind.web

Submodules
----------

climind.definitions module
--------------------------

.. automodule:: climind.definitions
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: climind
   :members:
   :undoc-members:
   :show-inheritance:
